==> foundation-2.6.1.tgz: package/TorsosFemaleMale/TorsosFemaleMale.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const TorsosFemaleMale = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M34.199 47.04v-6.415h.022c.163-5.466 1.39-10.528 3.382-14.767.223-.731.474-1.447.756-2.145-1.879-1.251-4.026-2.022-6.349-2.022-7.114 0-12.872 6.702-12.872 14.978 0 5.79 2.83 10.801 6.962 13.295L8.652 58.086c-1.088.511-1.804 1.739-1.804 3.111v13.771c0 1.846 1.289 3.341 2.874 3.341h11.532v-14.45c0-3.739 2.068-7.121 5.275-8.623l7.669-3.572V47.04z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M90.853 60.441l-15.66-7.47-6.621-3.159c.166-.105.324-.224.487-.335h8.695a2.438 2.438 0 002.438-2.438v-6.415h-.022c-.266-8.937-3.368-16.798-8.029-21.731-2.46-2.777-5.65-4.663-9.219-5.226a14.61 14.61 0 00-.474-.07c-.185-.023-.369-.046-.555-.062a13.701 13.701 0 00-1.202-.059c-.398 0-.793.023-1.186.057-.187.016-.372.039-.557.062-.157.02-.313.043-.469.068-3.532.553-6.694 2.405-9.145 5.134-4.712 4.927-7.853 12.832-8.121 21.827h-.022v6.415a2.438 2.438 0 002.438 2.438h8.719c.238.162.475.327.721.475l-6.342 2.953-16.168 7.53c-1.405.658-2.328 2.242-2.328 4.011v17.765c0 2.381 1.659 4.311 3.708 4.311h57.505c2.049 0 3.708-1.93 3.708-4.311V64.446c0-1.763-.908-3.332-2.299-4.005z"
  }));
});
TorsosFemaleMale.displayName = 'TorsosFemaleMale';
export const TorsosFemaleMaleDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/TorsosFemaleMale/TorsosFemaleMale.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var TorsosFemaleMale = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M34.199 47.04v-6.415h.022c.163-5.466 1.39-10.528 3.382-14.767.223-.731.474-1.447.756-2.145-1.879-1.251-4.026-2.022-6.349-2.022-7.114 0-12.872 6.702-12.872 14.978 0 5.79 2.83 10.801 6.962 13.295L8.652 58.086c-1.088.511-1.804 1.739-1.804 3.111v13.771c0 1.846 1.289 3.341 2.874 3.341h11.532v-14.45c0-3.739 2.068-7.121 5.275-8.623l7.669-3.572V47.04z"
  }), /*#__PURE__*/React.createElement("path", {
    d: "M90.853 60.441l-15.66-7.47-6.621-3.159c.166-.105.324-.224.487-.335h8.695a2.438 2.438 0 002.438-2.438v-6.415h-.022c-.266-8.937-3.368-16.798-8.029-21.731-2.46-2.777-5.65-4.663-9.219-5.226a14.61 14.61 0 00-.474-.07c-.185-.023-.369-.046-.555-.062a13.701 13.701 0 00-1.202-.059c-.398 0-.793.023-1.186.057-.187.016-.372.039-.557.062-.157.02-.313.043-.469.068-3.532.553-6.694 2.405-9.145 5.134-4.712 4.927-7.853 12.832-8.121 21.827h-.022v6.415a2.438 2.438 0 002.438 2.438h8.719c.238.162.475.327.721.475l-6.342 2.953-16.168 7.53c-1.405.658-2.328 2.242-2.328 4.011v17.765c0 2.381 1.659 4.311 3.708 4.311h57.505c2.049 0 3.708-1.93 3.708-4.311V64.446c0-1.763-.908-3.332-2.299-4.005z"
  }));
});
TorsosFemaleMale.displayName = 'TorsosFemaleMale';
export var TorsosFemaleMaleDimensions = {
  height: 100,
  width: 100
};
